@@ -10,7 +10,13 @@ from .device import Device, Interface
 from .execution import Execution
 from .exceptions import *
 from .logger import Logger
-from .studio import InputError, Studio
+from .studio import (
+    Studio,
+    setStudioInput,
+    getStudioInputs,
+    extractInputElems,
+    extractStudioInfoFromArgs
+)
 from .topology import Connection, Topology
 from .user import User
 
